Crate monotone_crescendo

Crate monotone_crescendo 

A library for calculating the least number of flips needed to make a binary string monotone increasing. Also contains utility functions for allocating WebAssembly linear memory and returning a pointer to it, as well as deallocating said memory.

Modules

solution
Implementations of the monotone increasing problem
wasm_memory
Utilities for interacting with WASM’s linear memory